{% load url from future %}{% load i18n gadjo %}<!DOCTYPE html>
<html>
  <head>
    <meta charset="utf-8"/>
    <title>{% block page-title %}{% endblock %}</title>
    <link rel="stylesheet" type="text/css" media="all" href="{{ STATIC_URL }}css/gadjo.css"/>
    {% block gadjo-js %}
    <link rel="stylesheet" type="text/css" media="all"
            href="{% xstatic 'jquery-ui' 'themes/smoothness/jquery-ui.min.css' %}"/>
    <script src="{% xstatic 'jquery' 'jquery.min.js' %}"></script>
    <script src="{% xstatic 'jquery-ui' 'jquery-ui.min.js' %}"></script>
    <script src="{{ STATIC_URL }}js/gadjo.js"></script>
    {% endblock %}
    {% block css %}
    <link rel="stylesheet" type="text/css" media="all" href="{{ STATIC_URL }}css/style.css"/>
    {% endblock %}
    {% block extrascripts %}
    {% endblock %}
  </head>
  <body {% block bodyargs %}{% endblock %}>
  <div id="top">
    <div id="sidepage">
      <span id="applabel"> </span>
    </div>
    {% block user-links %}
    <ul class="user-info">
  {% if user.is_authenticated %}
  <li class="ui-name">{{ user.get_full_name }}</li>
  <li class="ui-logout"><a href="{% block logout-url %}index.html{% endblock %}">{% trans "Logout" %}</a></li>
          {% endif %}
  </ul>
        {% endblock %}
  </div>
  <div id="main">
    <div id="header">
      <h1>{% block site-title %}{% endblock %}</h1>
    </div>
    <div id="main-content">
      <div id="more-user-links">
        {% block more-user-links %}
          <span id="breadcrumb">
          {% block breadcrumb %}
          <a href="{% block homepage-url %}/{% endblock %}">{% block homepage-title %}{% trans "Homepage" %}{% endblock %}</a>
          {% endblock %}
          </span>
        {% endblock %}
      </div>
      <div id="content">

        <div id="appbar">
          {% block appbar %}
          {% endblock %}
        </div>

{% block messages %}
{% if messages %}
<ul class="messages">
    {% for message in messages %}
    <li{% if message.tags %} class="{{ message.tags }}"{% endif %}>{{ message }}</li>
    {% endfor %}
</ul>
<script>
(function () {
    var $ = jQuery;
    $(document).ready(function() {
      $('.messages').delay(5000).fadeOut('slow');
    });
})();
</script>
{% endif %}
{% endblock %}

        {% block beforecontent %}
        {% endblock %}

        {% block content %}
        {% endblock %}
        <br style="clear: both;"/>

      </div> <!-- #content -->
    </div> <!-- #main-content -->

  </div> <!-- #main -->


  <div id="footer">
    {% block footer %}
      Copyright &copy; 2014 Entr'ouvert
    {% endblock %}
  </div>

  {% block page-end %}
  {% endblock %}
  </body>
</html>
